==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/colorbutton/lang/no.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'no', {
	auto: 'Automatisk',
	bgColorTitle: 'Bakgrunnsfarge',
	colors: {
		'000': 'Svart',
		'800000': 'Rødbrun',
		'8B4513': 'Salbrun',
		'2F4F4F': 'Grønnsvart',
		'008080': 'Blågrønn',
		'000080': 'Marineblått',
		'4B0082': 'Indigo',
		'696969': 'Mørk grå',
		B22222: 'Mørkerød',
		A52A2A: 'Brun',
		DAA520: 'Lys brun',
		'006400': 'Mørk grønn',
		'40E0D0': 'Turkis',
		'0000CD': 'Medium blå',
		'800080': 'Purpur',
		'808080': 'Grå',
		F00: 'Rød',
		FF8C00: 'Mørk oransje',
		FFD700: 'Gull',
		'008000': 'Grønn',
		'0FF': 'Cyan',
		'00F': 'Blå',
		EE82EE: 'Fiolett',
		A9A9A9: 'Svak grå',
		FFA07A: 'Rosa-oransje',
		FFA500: 'Oransje',
		FFFF00: 'Gul',
		'00FF00': 'Lime',
		AFEEEE: 'Svak turkis',
		ADD8E6: 'Lys Blå',
		DDA0DD: 'Plomme',
		D3D3D3: 'Lys grå',
		FFF0F5: 'Svak lavendelrosa',
		FAEBD7: 'Antikk-hvit',
		FFFFE0: 'Lys gul',
		F0FFF0: 'Honningmelon',
		F0FFFF: 'Svakt asurblått',
		F0F8FF: 'Svak cyan',
		E6E6FA: 'Lavendel',
		FFF: 'Hvit',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Orange', // MISSING
		'E67E22': 'Carrot', // MISSING
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Silver', // MISSING
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Dark Gray' // MISSING
	},
	more: 'Flere farger...',
	panelTitle: 'Farger',
	textColorTitle: 'Tekstfarge'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/colorbutton/lang/no.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'no', {
	auto: 'Automatisk',
	bgColorTitle: 'Bakgrunnsfarge',
	colors: {
		'000': 'Svart',
		'800000': 'Rødbrun',
		'8B4513': 'Salbrun',
		'2F4F4F': 'Grønnsvart',
		'008080': 'Blågrønn',
		'000080': 'Marineblått',
		'4B0082': 'Indigo',
		'696969': 'Mørk grå',
		B22222: 'Mørkerød',
		A52A2A: 'Brun',
		DAA520: 'Lys brun',
		'006400': 'Mørk grønn',
		'40E0D0': 'Turkis',
		'0000CD': 'Medium blå',
		'800080': 'Purpur',
		'808080': 'Grå',
		F00: 'Rød',
		FF8C00: 'Mørk oransje',
		FFD700: 'Gull',
		'008000': 'Grønn',
		'0FF': 'Cyan',
		'00F': 'Blå',
		EE82EE: 'Fiolett',
		A9A9A9: 'Svak grå',
		FFA07A: 'Rosa-oransje',
		FFA500: 'Oransje',
		FFFF00: 'Gul',
		'00FF00': 'Lime',
		AFEEEE: 'Svak turkis',
		ADD8E6: 'Lys Blå',
		DDA0DD: 'Plomme',
		D3D3D3: 'Lys grå',
		FFF0F5: 'Svak lavendelrosa',
		FAEBD7: 'Antikk-hvit',
		FFFFE0: 'Lys gul',
		F0FFF0: 'Honningmelon',
		F0FFFF: 'Svakt asurblått',
		F0F8FF: 'Svak cyan',
		E6E6FA: 'Lavendel',
		FFF: 'Hvit',
		'1ABC9C': 'Kraftig turkis',
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Lyseblå',
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Gråblå',
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Mørk turkis',
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Signalblå',
		'8E44AD': 'Mørk fiolett',
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Orange',
		'E67E22': 'Gulrotfarge',
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Lys sølv',
		'95A5A6': 'Lys gråturkis',
		'DDD': 'Lysegrå',
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Signalrød',
		'BDC3C7': 'Sølv',
		'7F8C8D': 'Gråturkis',
		'999': 'Mørkegrå'
	},
	more: 'Flere farger...',
	panelTitle: 'Farger',
	textColorTitle: 'Tekstfarge'
} );
